@@ -4,6 +4,7 @@ import osmgpsmap
 import gobject
 import os
 import evolution
+import base64
 
 
 class DetailsWindow(hildon.StackableWindow):
@@ -18,6 +19,26 @@ class DetailsWindow(hildon.StackableWindow):
 
         self.osmMapa.set_autorotate_for_object(self)
 
+        tlldbox = gtk.VBox()
+
+        if len(point) == 2:
+            print "point only LL use geonames to build it"
+            ll = point
+            point = [
+                     ll[0],
+                     ll[1],
+                     "What's here?",
+                     "-",
+                     gtk.gdk.pixbuf_new_from_file("./maps/ico_igla_32_32.png"),
+                     None,
+                     7  ]
+            p = self.osmMapa.get_plugin("Google - geonames")
+            if p:
+                p.ref_dawnload( ll[0], ll[1])
+                self.geonames_downloader_loop(p, tlldbox, ll[0],ll[1])
+
+
+
         self.details_share = ""
 
         #self.set_default_size(500, 500)
@@ -32,7 +53,6 @@ class DetailsWindow(hildon.StackableWindow):
 
 
         lrbox = gtk.HBox()
-        tlldbox = gtk.VBox()
 
         tlldbox.pack_start( self.get_label("<big>%s</big>" % point[3]) , False)
         self.details_share = "%s " % point[3]
@@ -56,7 +76,7 @@ class DetailsWindow(hildon.StackableWindow):
                         if plugin[1] == "Google - places":
                             ref_downloader = plugin[0]
                             ref_downloader.get_reference( d['reference'] )
-                            self.ref_downloader_loop(ref_downloader, tlldbox)
+                            self.ref_downloader_loop(ref_downloader, tlldbox, point)
                             break
             except:
                 pass
@@ -68,6 +88,28 @@ class DetailsWindow(hildon.StackableWindow):
         tlldbox.pack_start( self.get_label("Longitude: <small>%f</small>" % point[1]), False)
         tlldbox.pack_start( self.get_label("Point from : <small>%s</small>" % point[2]), False)
 
+        try:
+            if point[7]['address']:
+                tlldbox.pack_start( self.get_label("Addres: <small>%s</small>" % point[7]['address']), False)
+                self.details_share = "%s %s" % ( point[7]['address'], self.details_share )
+        except Exception, e:
+                print "add reference error [7] address",e
+        try:
+            if point[7]['tel']:
+                self.details_share = "%stel: %s" % (self.details_share, point[7]['tel'])
+
+                hbox0 = gtk.HBox()
+                l = gtk.Label("Phone: ")
+                hbox0.pack_start(l, False)
+
+                bt_phone = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"%s" % point[7]['tel'])
+                bt_phone.connect("clicked",self.on_call_clicked, point[7]['tel'] )
+                hbox0.pack_start(bt_phone, False)
+
+                tlldbox.pack_start( hbox0, True)
+        except Exception, e:
+                print "add reference error [7] tel",e
 
         self.bt_hbox = gtk.HBox()
 
@@ -139,9 +181,20 @@ class DetailsWindow(hildon.StackableWindow):
         #self.run()
         #self.destroy()
 
-    def ref_downloader_loop(self, ref_downloader, tlldbox):
+    def geonames_downloader_loop(self,ref_downloader, tlldbox, lat,lon):
         if ref_downloader.ref_result == []:
-            gobject.timeout_add( 1000, self.ref_downloader_loop, ref_downloader, tlldbox )
+            gobject.timeout_add( 1000, self.geonames_downloader_loop, ref_downloader, tlldbox, lat,lon )
+        else:
+            try:
+                tlldbox.pack_start( self.get_label("Addres: <small>%s</small>" % ref_downloader.ref_result[1]), False)
+                self.details_share = "%s %s" % ( ref_downloader.ref_result[1], self.details_share )
+                tlldbox.show_all()
+            except Exception, e:
+                print "add reference error",e
+
+    def ref_downloader_loop(self, ref_downloader, tlldbox, point):
+        if ref_downloader.ref_result == []:
+            gobject.timeout_add( 1000, self.ref_downloader_loop, ref_downloader, tlldbox, point )
         else:
             try:
                 tlldbox.pack_start( self.get_label("Addres: <small>%s</small>" % ref_downloader.ref_result[1]), False)
@@ -168,7 +221,7 @@ class DetailsWindow(hildon.StackableWindow):
 
                 bt_addContact = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
                                hildon.BUTTON_ARRANGEMENT_VERTICAL,"Add Contact")
-                bt_addContact.connect("clicked",self.on_bt_addContact,ref_downloader.ref_result)
+                bt_addContact.connect("clicked",self.on_bt_addContact,ref_downloader.ref_result, point)
                 self.bt_hbox.pack_start( bt_addContact, True)
                 bt_addContact.show_all()
 
@@ -180,17 +233,36 @@ class DetailsWindow(hildon.StackableWindow):
         #os.system(  "dbus-send --system --dest=com.nokia.csd.Call --type=method_call --print-reply /com/nokia/csd/call com.nokia.csd.Call.CreateWith string:\"%s\" uint32:0 &" % tel )
         os.system(  "dbus-send --system --type=method_call --print-reply --dest=com.nokia.csd.Call /com/nokia/csd/call com.nokia.csd.Call.CreateWith string:\"%s\" uint32:0" % tel.replace(" ", "") )
 
-    def on_bt_addContact(self,w, store):
+    def on_bt_addContact(self,w, store, point):
         print "--- add concat --- "
         addresses = evolution.ebook.open_addressbook('default')
-        c = evolution.ebook.EContact("""BEGIN:VCARD
+        img = ""
+        try:
+            i = point[4]
+            i.save( "/tmp/.yosm_pix.png", "png" )
+            f = open("/tmp/.yosm_pix.png","r")
+            l = f.read()
+            base_img = base64.encodestring(l)
+
+
+
+            img = """PHOTO;TYPE=PNG;ENCODING=BASE64:
+    """+base_img.replace("\n","\n\t")+"""
+
+"""
+        except:
+            pass
+
+        vcard = """BEGIN:VCARD
 VERSION:3.0
 FN:"""+store[0]+"""
 TEL;TYPE=CELL:"""+store[2].replace(" ","")+"""
 NOTE:add by yosmapa
-ADR:"""+store[1]+""";;;;;;
-END:VCARD
-BEGIN:VCARD""")
+ADR:;"""+store[1].replace("  "," ")+""";;;;;
+"""+img+"""END:VCARD"""
+        print "---- vcard ---\n",vcard,"\n-----------vcard------"
+
+        c = evolution.ebook.EContact(vcard)
         addresses.add_contact(c)
         self.osmMapa.showBanner("Contact added.")
         print "--- add concat DONE --- "
@@ -231,7 +303,7 @@ BEGIN:VCARD""")
         hbox = gtk.HBox( spacing = 5 )
         l0 = gtk.Label()
         l0.set_line_wrap( True )
-        l0.set_markup( str )
+        l0.set_markup( str.replace("&","&amp;") )
         hbox.pack_start( l0, False)
 
         l1 = gtk.Label()
