@@ -2,6 +2,8 @@ import hildon
 import gtk
 import gobject
 
+from h_UI_selectContact import *
+
 class SearchDialog( hildon.StackableWindow ):
     def __init__(self, osmMapa, config ):
         hildon.StackableWindow.__init__(self)
@@ -73,6 +75,10 @@ class SearchDialog( hildon.StackableWindow ):
 
         self.plugins_query = []
 
+        ico = gtk.Image()
+        ico.set_from_file( "./imgs/ico_mans_32_32.png")
+        hbox.pack_start(ico,False)
+
         for p in self.osmMapa.find_plugins:
             try:
                 if p[0].ui_search:
@@ -171,28 +177,39 @@ class SearchDialog( hildon.StackableWindow ):
 
         for p in self.plugins_query:
 
-            res = p[0].search_query( self.CONFIG['search'] )
+            if 1:#"Google - geonames" <> p[0].get_name():
+                res = p[0].search_query( self.CONFIG['search'] )
 
-            hbox = gtk.HBox()
+                hbox = gtk.HBox()
 
-            l = gtk.Label( "%s (%i):" % (p[0].get_name(), len(res)) )
-            hbox.pack_start(l,False)
-            l = gtk.Label()
-            hbox.pack_start(l,True)
-            mvbox.pack_start( hbox, False )
+                l = gtk.Label( "%s (%i):" % (p[0].get_name(), len(res)) )
+                hbox.pack_start(l,False)
+                l = gtk.Label()
+                hbox.pack_start(l,True)
+                mvbox.pack_start( hbox, False )
 
-            if len(p) == 2:
-                vbox = gtk.VBox()
-                p[1] = vbox
-                mvbox.pack_start( vbox, False)
-                self.make_delay_iter_for_ui_thread( p )
+                if len(p) == 2:
+                    vbox = gtk.VBox()
+                    p[1] = vbox
+                    mvbox.pack_start( vbox, False)
+                    self.make_delay_iter_for_ui_thread( p )
 
-            for i in res:
-                mvbox.pack_start(self.add_item_to_box(i),False)
-                self.osmMapa.show_find_results.append(  i )
+                for i in res:
+                    mvbox.pack_start(self.add_item_to_box(i),False)
+                    self.osmMapa.show_find_results.append(  i )
+
+                h = gtk.HSeparator()
+                mvbox.pack_start(h,True)
+
+
+        # ----- search in contact book
+        ab = SelectContact(self.osmMapa)
+        res = ab.get_address_for( self.CONFIG['search'] )
+        print "results from address book [",len(res),"]"
+        if len(res) > 0:
+            self.make_contact_loop( res, None, 0 )
+        # ----- search in contact book
 
-            h = gtk.HSeparator()
-            mvbox.pack_start(h,True)
 
         #d.show_all()
         self.destroy()
@@ -200,6 +217,42 @@ class SearchDialog( hildon.StackableWindow ):
         d.destroy()
         self.osmMapa.recalculate_center_and_zoom()
 
+    def make_contact_loop(self, res, geoname, item_search):
+        print "--",item_search,"[",res[item_search][3],"] search fon [",res[item_search][7]['address'],"]"
+        if geoname == None:
+            geoname = self.osmMapa.get_plugin("Google - geonames").makeClone( self.osmMapa, self.CONFIG)
+
+        if res[item_search][7]['geoname_status'] == 0:
+            print "--geoname_ref for contact ",item_search," 1"
+            res[item_search][7]['geoname_status'] = 1
+            geoname.ref_download_by_str( res[item_search][7]['address'] )
+            gobject.timeout_add( 1000, self.make_contact_loop, res, geoname, item_search )
+
+        elif res[item_search][7]['geoname_status'] == 1 and geoname.ref_result == []:
+            print "--geoname_ref for contact ",item_search," 2"
+            gobject.timeout_add( 1000, self.make_contact_loop, res, geoname, item_search )
+
+        elif res[item_search][7]['geoname_status'] == 1 and geoname.ref_result == [0]:
+            print "--geoname_ref for contact ",item_search," 3"
+            item_search+=1
+            if (len( res )-1)< item_search:
+                self.make_contact_loop( res, None, item_search )
+
+        elif res[item_search][7]['geoname_status'] == 1 and len(geoname.ref_result) > 1 and res[item_search][7]['geoname_status'] == 1:
+            print "--geoname_ref for contact ",item_search," 4"
+            res[item_search][7]['geoname_status'] = 2
+            res[item_search][0] = geoname.ref_result[0]
+            res[item_search][1] = geoname.ref_result[1]
+            print "=======- ready to add [",item_search,"]",res[item_search]
+            self.osmMapa.show_find_results.append( res[item_search] )
+            item_search+=1
+            if len( res )> item_search:
+                print "--geoname_ref for contact search next ",item_search
+                self.make_contact_loop( res, None, item_search )
+            else:
+                print "--geoname_ref for contact DONE---------"
+                self.osmMapa.recalculate_center_and_zoom()
+
 
     def make_delay_iter_for_ui_thread(self, plugin):
         print "make_delay_iter_for_ui_thread ",plugin[0].get_name()
