@@ -14,65 +14,10 @@ import re
 import thread
 from threading import Thread
 
+from decode_line import *
 
 
 
-
-
-
-def decode_line(encoded):
-
-    """Decodes a polyline that was encoded using the Google Maps method.
-
-    See http://code.google.com/apis/maps/documentation/polylinealgorithm.html
-
-    This is a straightforward Python port of Mark McClure's JavaScript polyline decoder
-    (http://facstaff.unca.edu/mcmcclur/GoogleMaps/EncodePolyline/decode.js)
-    and Peter Chng's PHP polyline decode
-    (http://unitstep.net/blog/2008/08/02/decoding-google-maps-encoded-polylines-using-php/)
-    """
-
-    encoded_len = len(encoded)
-    index = 0
-    array = []
-    lat = 0
-    lng = 0
-
-    while index < encoded_len:
-
-        b = 0
-        shift = 0
-        result = 0
-
-        while True:
-            b = ord(encoded[index]) - 63
-            index = index + 1
-            result |= (b & 0x1f) << shift
-            shift += 5
-            if b < 0x20:
-                break
-
-        dlat = ~(result >> 1) if result & 1 else result >> 1
-        lat += dlat
-
-        shift = 0
-        result = 0
-
-        while True:
-            b = ord(encoded[index]) - 63
-            index = index + 1
-            result |= (b & 0x1f) << shift
-            shift += 5
-            if b < 0x20:
-                break
-
-        dlng = ~(result >> 1) if result & 1 else result >> 1
-        lng += dlng
-
-        array.append((lat * 1e-5, lng * 1e-5))
-
-    return array
-
 class MyZoomSelect(gtk.Dialog):
 
     def act_download(self,widget):
