@@ -62,7 +62,7 @@ gtk.gdk.threads_init()
 
 
 name = "yosmapa"
-version = "0.19"
+version = "0.19-19"
 
 
 
@@ -350,6 +350,8 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
         else:
             x = gdkeventbutton.x
             y = gdkeventbutton.y
+            t = time.time()
+            self.osmMapa.cliked_at_xyt = [ x,y, t ]
             print "click at :",x,",",y
 
 
@@ -371,37 +373,7 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
                     if type(c[6]) == list:
                         self.on_details(None,c[6])
 
-                    """
-                    else:
-                        m = gtk.Menu()
-                        latc,lonc = self.osmMapa.get_may_current_ll()
-                        dis = self.osmMapa.distance_to_string( self.osmMapa.distance( latc, lonc, c[4], c[5]) )
 
-                        mi = gtk.MenuItem("___________Distans it: %s" % dis)
-                        m.append(mi)
-
-                        mi = gtk.MenuItem("___________Center to")
-                        mi.connect("activate",self.on_set_center,c[4],c[5])
-                        m.append(mi)
-
-                        if CONFIG['POI']:
-                            mi = gtk.MenuItem("___________Add as POI")
-                            mi.connect("activate",self.on_add_as_poi,c[4],c[5])
-                            m.append(mi)
-
-                        if CONFIG['Google - routesearch']:
-                            mi = gtk.MenuItem("___________Route to it")
-                            mi.connect("activate",self.on_route_to_it,c[4],c[5])
-                            m.append(mi)
-
-                        if type(c[6]) == list:
-                            mi = gtk.MenuItem("___________Details")
-                            mi.connect("activate",self.on_details,c[6])
-                            m.append(mi)
-
-                        m.show_all()
-                        m.popup( None, None, None , 2, 0)
-                    """
 
         if timing_osd:
             print "YosmapaOSD press in:",( time.time()-t )
@@ -410,32 +382,6 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
     def on_details(self, w, point):
         w = DetailsWindow( self.osmMapa, point, CONFIG )
 
-    """
-    def on_route_to_it(self, w, lat, lon):
-        p = None
-        for plugin in self.osmMapa.plugins_list:
-            if plugin[1] == "Google - routesearch":
-                p = plugin[0]
-                break
-        if p <> None:
-            CONFIG['google_routesearch_from'] = "my current location"
-            CONFIG['google_routesearch_to'] = "loc:%f+%f" %( lat, lon)
-            p.search_action()
-
-    def on_add_as_poi(self, w, lat, lon):
-        poi = None
-        for plugin in self.osmMapa.plugins_list:
-            if plugin[1] == "POI":
-                poi = plugin[0]
-                break
-        if poi <> None:
-            self.osmMapa.osm.set_center( lat,lon)
-            poi.on_add( None,None )
-
-
-    def on_set_center(self, w,lat, lon):
-        self.osmMapa.osm.set_center_and_zoom( lat,lon, 16)
-    """
 gobject.type_register(YosmapaOSD)
 
 
@@ -532,6 +478,7 @@ class UI(hildon.StackableWindow):
         return bt_sms
     def send_to_contact_step1(self, w, str_to_send):
         s = SelectContact(self,str_to_send)
+        s.start_dialog()
     def send_to_contact_step2(self, telNr, str_to_send):
         if telNr=="" or str_to_send == "":
             return None
@@ -543,6 +490,7 @@ class UI(hildon.StackableWindow):
 
         text = gtk.TextView()
         text.set_size_request(240, 240)
+        text.set_wrap_mode(True)
         tb = text.get_buffer()
         tb.set_text( str_to_send )
         text.set_buffer( tb )
@@ -667,6 +615,8 @@ class UI(hildon.StackableWindow):
         self.clikable_icons = []
         self.cliked_item = []
 
+        self.cliked_at_xyt = [0,0,0]
+
         self.markers = []
 
         self.window_rotate = -1
@@ -1117,7 +1067,6 @@ class UI(hildon.StackableWindow):
         self.osm.set_zoom( CONFIG['zoom'] )
 
 
-
     def print_tiles(self):
         if self.osm.props.tiles_queued != 0:
             print self.osm.props.tiles_queued, 'tiles queued'
@@ -1133,9 +1082,82 @@ class UI(hildon.StackableWindow):
             self.osm.set_zoom(self.osm.props.zoom - 1)
 
 
+    def map_release_menu(self, xR, yR ):
+        t = time.time()
+
+        if xR == self.cliked_at_xyt[0] and yR == self.cliked_at_xyt[1] and (t-0.5) > self.cliked_at_xyt[2]:
+            print "menu tab map show !"
+
+            m = gtk.Menu()
+            latc,lonc = self.get_may_current_ll()
+
+            rlat, rlon = self.osm.get_co_ordinates(int(xR), int(yR))
+            lat = math.degrees(rlat)
+            lon = math.degrees(rlon)
+
+            dis = self.distance_to_string( self.distance( latc, lonc,lat,lon) )
+
+            mi = gtk.MenuItem("Distans it: %s\n" % dis)
+            m.append(mi)
+
+            mi = gtk.MenuItem("\nCenter to\n")
+            mi.connect("activate",self.onM_set_center,lat,lon)
+            m.append(mi)
+
+            if CONFIG['POI']:
+                mi = gtk.MenuItem("\nAdd as POI\n")
+                mi.connect("activate",self.onM_add_as_poi,lat,lon)
+                m.append(mi)
+
+            if CONFIG['Google - routesearch']:
+                mi = gtk.MenuItem("\nRoute to\n")
+                mi.connect("activate",self.onM_route_to_it,lat,lon)
+                m.append(mi)
+
+
+            #if type(c[6]) == list:
+            if CONFIG['Google - geonames']:
+                mi = gtk.MenuItem("\nDetails")
+                mi.connect("activate",self.onM_details,lat,lon)
+                m.append(mi)
+
+            m.show_all()
+            m.popup( None, None, None , 2, 0)
+
+    def onM_details(self,w, lat,lon):
+        print "-- details from menu -- "
+        dw = DetailsWindow( self, [lat,lon], CONFIG )
+        print "-- details from menu -- "
+
+    def onM_route_to_it(self, w, lat, lon):
+        p = self.get_plugin( "Google - routesearch" )
+        if p <> None:
+            CONFIG['google_routesearch_from'] = "my current location"
+            CONFIG['google_routesearch_to'] = "loc:%f+%f" %( lat, lon)
+            p.search_action()
+
+    def onM_add_as_poi(self, w, lat, lon):
+        poi = self.get_plugin("POI")
+        if poi <> None:
+            self.osm.set_center( lat,lon)
+            poi.on_add( None,None )
+
+    def onM_set_center(self, w,lat, lon):
+        self.osm.set_center_and_zoom( lat,lon, 16)
+
+
+
     def map_clicked(self, osm, event):
         if CONFIG['work_work_work']:
             print "config update"
+
+
+            x = event.x
+            y = event.y
+
+            self.map_release_menu(x, y)
+            print "click at :",x,",",y
+
             CONFIG['lat'] = self.osm.props.latitude
             CONFIG['lon'] = self.osm.props.longitude
             CONFIG['zoom'] = self.osm.props.zoom
@@ -1259,12 +1281,8 @@ gobject.type_register(PluginsLayer)
 
 
 if __name__ == "__main__":
-    print "ebook test --"
-
-    #s = SelectContact()
-    #print s.runIt()
-
-
+    t = time.time()
+    print "__main__"
 
     config_load( CONFIG )
     u = UI()
@@ -1294,7 +1312,9 @@ if __name__ == "__main__":
     except:
          u.welcomeScreenInit()
 
+
     if os.name == "nt": gtk.gdk.threads_enter()
+    print "Up and running in: ",(time.time()-t)
     gtk.main()
     if os.name == "nt": gtk.gdk.threads_leave()
     config_save( CONFIG )
